@@ -10,6 +10,7 @@ from UnleashClient.periodic_tasks import fetch_and_load_features, aggregate_and_
 from UnleashClient.strategies import ApplicationHostname, Default, GradualRolloutRandom, \
     GradualRolloutSessionId, GradualRolloutUserId, UserWithId, RemoteAddress, FlexibleRollout
 from UnleashClient.constants import METRIC_LAST_SENT_TIME, DISABLED_VARIATION, ETAG
+from UnleashClient.loader import load_features
 from .utils import LOGGER
 from .deprecation_warnings import strategy_v2xx_deprecation_check
 from .cache import BaseCache, FileCache
@@ -34,6 +35,7 @@ class UnleashClient:
     :param cache_directory: Location of the cache directory. When unset, FCache will determine the location.
     :param verbose_log_level: Numerical log level (https://docs.python.org/3/library/logging.html#logging-levels) for cases where checking a feature flag fails.
     :param cache: Custom cache implementation that extends UnleashClient.cache.BaseCache.  When unset, UnleashClient will use Fcache.
+    :param bootstraped: Whether cache has been boostrapped (i.e. pre-seeded) with Unleash configuration.  When true, UnleashClient will use initial configuration until the client is initialized.  See FileCache object for more information about bootstrapping.
     """
     def __init__(self,
                  url: str,
@@ -88,6 +90,7 @@ class UnleashClient:
             METRIC_LAST_SENT_TIME: datetime.now(timezone.utc),
             ETAG: ''
         })
+        self.unleash_bootstrapped = self.cache.bootstrapped
 
         # Mappings
         default_strategy_mapping = {
@@ -109,7 +112,11 @@ class UnleashClient:
         # Client status
         self.is_initialized = False
 
-    def initialize_client(self) -> None:
+        # Bootstrapping
+        if self.unleash_bootstrapped:
+            load_features(cache=self.cache, feature_toggles=self.features, strategy_mapping=self.strategy_mapping)
+
+    def initialize_client(self, fetch_toggles: bool = True) -> None:
         """
         Initializes client and starts communication with central unleash server(s).
 
@@ -119,6 +126,11 @@ class UnleashClient:
         * Provisioning poll
         * Stats poll
 
+        If `fetch_toggles` is `False`, feature toggle polling will be turned off
+        and instead the client will only load features from the cache. This is
+        usually used to cater the multi-process setups, e.g. Django, Celery,
+        etc.
+
         This will raise an exception on registration if the URL is invalid. It is done automatically if called inside a context manager as in:
 
         .. code-block:: python
@@ -134,18 +146,6 @@ class UnleashClient:
         if not self.is_initialized:
             try:
                 # Setup
-                fl_args = {
-                    "url": self.unleash_url,
-                    "app_name": self.unleash_app_name,
-                    "instance_id": self.unleash_instance_id,
-                    "custom_headers": self.unleash_custom_headers,
-                    "custom_options": self.unleash_custom_options,
-                    "cache": self.cache,
-                    "features": self.features,
-                    "strategy_mapping": self.strategy_mapping,
-                    "project": self.unleash_project_name
-                }
-
                 metrics_args = {
                     "url": self.unleash_url,
                     "app_name": self.unleash_app_name,
@@ -162,16 +162,36 @@ class UnleashClient:
                                     self.unleash_metrics_interval, self.unleash_custom_headers,
                                     self.unleash_custom_options, self.strategy_mapping)
 
-                fetch_and_load_features(**fl_args)  # type: ignore
+                if fetch_toggles:
+                    job_args = {
+                        "url": self.unleash_url,
+                        "app_name": self.unleash_app_name,
+                        "instance_id": self.unleash_instance_id,
+                        "custom_headers": self.unleash_custom_headers,
+                        "custom_options": self.unleash_custom_options,
+                        "cache": self.cache,
+                        "features": self.features,
+                        "strategy_mapping": self.strategy_mapping,
+                        "project": self.unleash_project_name,
+                    }
+                    job_func: Callable = fetch_and_load_features
+                else:
+                    job_args = {
+                        "cache": self.cache,
+                        "feature_toggles": self.features,
+                        "strategy_mapping": self.strategy_mapping,
+                    }
+                    job_func = load_features
 
+                job_func(**job_args)  # type: ignore
                 # Start periodic jobs
                 self.scheduler.start()
-                self.fl_job = self.scheduler.add_job(fetch_and_load_features,
+                self.fl_job = self.scheduler.add_job(job_func,
                                                      trigger=IntervalTrigger(
                                                          seconds=int(self.unleash_refresh_interval),
                                                          jitter=self.unleash_refresh_jitter,
                                                      ),
-                                                     kwargs=fl_args)
+                                                     kwargs=job_args)
 
                 if not self.unleash_disable_metrics:
                     self.metric_job = self.scheduler.add_job(aggregate_and_send_metrics,
@@ -225,7 +245,6 @@ class UnleashClient:
 
         :param feature_name: Name of the feature
         :param context: Dictionary with context (e.g. IPs, email) for feature toggle.
-        :param default_value: Allows override of default value. (DEPRECIATED, used fallback_function instead!)
         :param fallback_function: Allows users to provide a custom function to set default value.
         :return: Feature flag result
         """
@@ -234,7 +253,7 @@ class UnleashClient:
         # Update context with static values
         context.update(self.unleash_static_context)
 
-        if self.is_initialized:
+        if self.unleash_bootstrapped or self.is_initialized:
             try:
                 return self.features[feature_name].is_enabled(context)
             except Exception as excep:
@@ -264,7 +283,7 @@ class UnleashClient:
         context = context or {}
         context.update(self.unleash_static_context)
 
-        if self.is_initialized:
+        if self.unleash_bootstrapped or self.is_initialized:
             try:
                 return self.features[feature_name].get_variant(context)
             except Exception as excep:
